SUMMARY = "Graphics abstraction library for the Linux Framebuffer Device"
DESCRIPTION = "DirectFB is a thin library that provides developers \
with hardware graphics acceleration, input device handling and \
abstraction, an integrated windowing system with support for \
translucent windows and multiple display layers on top of the \
Linux framebuffer device."
SECTION = "libs"
LICENSE = "LGPLv2.1"
LIC_FILES_CHKSUM = "file://COPYING;md5=dcf3c825659e82539645da41a7908589"
HOMEPAGE = "http://directfb.org"

DEPENDS = "jpeg libpng freetype zlib sysfsutils"

PV = "1.4.17"
RV = "1.4-17"

# We need this to avoid build errors like this
#  ld: error: directfb-csource.o: requires unsupported dynamic reloc R_ARM_THM_MOVW_ABS_NC; recompile with -fPIC
#
# The libraries would have been compiled with -fPIC anyway even
# without this and we don't use the executables so we don't care about
# them.
TARGET_CFLAGS += "-fPIC"

inherit autotools binconfig pkgconfig

# The patch contains both Broadcom and BrightSign's changes
SRC_URI = "\
	http://directfb.org/downloads/Core/DirectFB-1.4/DirectFB-${PV}.tar.gz \
	file://DirectFB-${PV}-bs1.4.17+20170614T214253+b2d85630197e.patch \
"

SRC_URI[md5sum] = "12d6b3e83e2719fa1f387378fab2b441"
SRC_URI[sha256sum] = "065a8e3a655b7e633eb1c2cdf55956496a29e0b8bd8ca700f0a5507909c864de"

S = "${WORKDIR}/DirectFB-${PV}"
LDFLAGS_append = " -lm"

EXTRA_OECONF = "\
  --enable-freetype=yes \
  --enable-zlib \
  --with-gfxdrivers=none \
  --disable-fbdev \
  --with-inputdrivers=linuxinput \
  --enable-linux-input \
  --disable-sdl \
  --disable-vnc \
  --disable-x11 \
  --enable-debug \
  --enable-libmpeg3=no \
  --enable-mpeg2=no \
  --enable-video4linux=no \
  --disable-gif \
"

FILES_${PN}-dbg += "\
  ${libdir}/directfb-${RV}/*/*/.debug/*.so \
  ${libdir}/directfb-${RV}/*/.debug/*.so \
"

FILES_${PN}-dev += "\
  ${bindir}/directfb-config \
  ${libdir}/directfb-${RV}/systems/*.la \
  ${libdir}/directfb-${RV}/inputdrivers/*.la \
  ${libdir}/directfb-${RV}/interfaces/*/*.la \
  ${libdir}/directfb-${RV}/wm/*.la \
"

FILES_${PN} += "\
  ${libdir}/directfb-${RV}/systems/*.so \
  ${libdir}/directfb-${RV}/inputdrivers/*.so \
  ${libdir}/directfb-${RV}/interfaces/*/*.so \
  ${libdir}/directfb-${RV}/wm/*.so \
  ${datadir}/directfb-${PV} \
  ${libdir}/directfb-${RV}/gfxdrivers/*.so \
  ${libdir}/libinit.so \
  "
