SECTION = "console/utils"
DESCRIPTION = "Tools for performance analysis."
LICENSE = "lmbench-proprietary"
LIC_FILES_CHKSUM = "file://COPYING;md5=8ca43cbc842c2336e835926c2166c28b \
		    file://COPYING-2;md5=8e9aee2ccc75d61d107e43794a25cdf9"

PR = "r0"

inherit autotools-brokensep

SRC_URI = "${SOURCEFORGE_MIRROR}/lmbench/lmbench-${PV}.tgz \
	   file://lmbench-run"
SRC_URI[md5sum] = "b3351a3294db66a72e2864a199d37cbf"
SRC_URI[sha256sum] = "cbd5777d15f44eab7666dcac418054c3c09df99826961a397d9acf43d8a2a551"

S = "${WORKDIR}/lmbench-${PV}"

EXTRA_OEMAKE = 'CC="${CC}" AR="${AR}" CFLAGS="${CFLAGS}" \
		LDFLAGS="${LDFLAGS}" LD="${LD}" OS="${TARGET_SYS}" \
		TARGET="${TARGET_OS}" BASE="${prefix}"'


python do_unpack () {
    bb.build.exec_func('base_do_unpack', d)
    bb.build.exec_func('byebk_do_unpack', d)
}

byebk_do_unpack () {
	find ${S}/.. -name BitKeeper -o -name SCCS | xargs rm -rf
}

do_configure() {
	:
}

do_compile () {
	. ${CONFIG_SITE}
	if [ X"$ac_cv_uint" = X"yes" ]; then
		CFLAGS="${CFLAGS} -DHAVE_uint"
	fi
	install -d ${S}/bin/${TARGET_SYS}
	oe_runmake -C src
	sed -i -e 's,^SHAREDIR=.*$,SHAREDIR=${BRIGHTSIGN_BENCHMARKS_PATH}/${datadir}/${PN},;' \
		-e 's,^BINDIR=.*$,BINDIR=${BRIGHTSIGN_BENCHMARKS_PATH}/${bindir}/\nexport PATH=$PATH:$BINDIR\n,;' \
		-e 's,@OS@,${TARGET_SYS},;' ${WORKDIR}/lmbench-run
	sed -i -e 's,. ../bin/\$OS/\$CONFIG,CONFIG=/var/volatile/lmbench/config/\$OS/\$CONFIG,;' \
		-e 's,../bin/\$OS/\$CONFIG,/var/volatile/lmbench/config/\$OS/\$CONFIG,;' \
		-e 's,BASE=../,BASE=/var/volatile/lmbench/,;' \
		-e 's,../\${RESULTS},\${RESULTS},;' scripts/results

	sed -i -e 's,^C=../bin/\$OS.*$,C=/var/volatile/lmbench/config/${TARGET_SYS}/\`../scripts/config\`,;' scripts/config-run

	echo -e "#!/bin/sh\n\necho ${TARGET_SYS}\n" > scripts/os
}

do_install () {
        mkdir -p ${D}${libdir}/lmbench
	oe_runmake 'BASE=${D}${prefix}' \
		    -C src install
	install -d ${D}${localstatedir}/lib/lmbench/config \
		   ${D}${localstatedir}/run/lmbench \
		   ${D}${bindir}
	install -m 0755 ${WORKDIR}/lmbench-run ${D}${bindir}/
	mkdir -p ${D}${mandir}
	mv ${D}${prefix}/man/* ${D}${mandir}/
	install -d ${D}${datadir}/lmbench/bin
	ln -sf ${BRIGHTSIGN_BENCHMARKS_PATH}/bin ${D}${datadir}/lmbench/bin/${TARGET_SYS}
	ln -sf /var/volatile/lmbench/results ${D}${datadir}/lmbench/results
	install -m 0755 ${S}/scripts/lmbench ${D}${bindir}
	install -d ${D}${datadir}/lmbench/scripts
	install -m 0755 ${S}/scripts/* ${D}${datadir}/lmbench/scripts
	# remove perl dependency
	rm ${D}${datadir}/lmbench/scripts/getresults
}

FILES_${PN} += "${datadir}/lmbench"
