#!/bin/sh

BS_LTTNG_TRACEFILE_SIZE=${BS_LTTNG_TRACEFILE_SIZE:-5M}
BS_LTTNG_TRACEFILE_COUNT=${BS_LTTNG_TRACEFILE_COUNT:-2}
BS_LTTNG_SUBBUF_SIZE=${BS_LTTNG_SUBBUF_SIZE:-128k}
BS_LTTNG_NUM_SUBBUF=${BS_LTTNG_NUM_SUBBUF:-4}

LTTNG_MODULES="
lttng-clock \
lttng-lib-ring-buffer \
lttng-statedump \
lttng-kprobes \
lttng-kretprobes \
lttng-ftrace \
lttng-tracer \
lttng-ring-buffer-metadata-client \
lttng-ring-buffer-client-discard \
lttng-ring-buffer-client-overwrite \
lttng-ring-buffer-client-mmap-discard \
lttng-ring-buffer-client-mmap-overwrite \
lttng-ring-buffer-metadata-mmap-client \
lttng-probe-sched \
lttng-probe-irq \
lttng-probe-printk \
lttng-probe-kmem \
lttng-probe-gpio \
lttng-probe-signal \
lttng-probe-timer \
lttng-probe-workqueue \
"

case "$1" in
    start)
        mkdir -p "${LTTNG_HOME}"
        have_kernel_probes=0
        if [ -f /proc/sys/kernel/ftrace_enabled ]; then
            have_kernel_probes="$(cat /proc/sys/kernel/ftrace_enabled)"
        fi
        lttng create bs
        lttng enable-channel \
            -u channel0 \
            --overwrite \
            --subbuf-size ${BS_LTTNG_SUBBUF_SIZE} \
            --num-subbuf ${BS_LTTNG_NUM_SUBBUF} \
            --tracefile-size ${BS_LTTNG_TRACEFILE_SIZE} \
            --tracefile-count ${BS_LTTNG_TRACEFILE_COUNT}

        # Circular buffer for high-frequency events e.g. v-sync GL jobs
        lttng enable-channel \
            --overwrite \
            -u channel_high_freq \
            --subbuf-size 128k \
            --num-subbuf 2 \
            --tracefile-size 128k \
            --tracefile-count 2

        if [ $have_kernel_probes -eq 1 ]; then
            for m in $LTTNG_MODULES; do
                insmod /lib/modules/$m.ko
            done
            lttng enable-channel \
                -k channel0 \
                --overwrite \
                --subbuf-size ${BS_LTTNG_SUBBUF_SIZE} \
                --num-subbuf ${BS_LTTNG_NUM_SUBBUF} \
                --tracefile-size ${BS_LTTNG_TRACEFILE_SIZE} \
                --tracefile-count ${BS_LTTNG_TRACEFILE_COUNT}
        fi
        ;;
esac
